diff --git a/apps/web/src/features/auth/__tests__/auth.integration.test.tsx b/apps/web/src/features/auth/__tests__/auth.integration.test.tsx
index dde19b6fd..af0b4ba74 100644
--- a/apps/web/src/features/auth/__tests__/auth.integration.test.tsx
+++ b/apps/web/src/features/auth/__tests__/auth.integration.test.tsx
@@ -2,6 +2,7 @@ import { describe, it, expect, vi, beforeEach, afterEach } from 'vitest';
import { render, screen, waitFor } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import { MemoryRouter, Routes, Route } from 'react-router-dom';
+import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { LoginPage } from '../pages/LoginPage';
import { RegisterPage } from '../pages/RegisterPage';
import { ForgotPasswordPage } from '../pages/ForgotPasswordPage';
@@ -100,18 +101,23 @@ vi.mock('react-router-dom', async () => {
};
});
// Helper function to render with router
const renderWithRouter = (
initialEntries: string[],
path: string,
component: React.ReactElement,
) => {
+ const queryClient = new QueryClient({
+ defaultOptions: { queries: { retry: false }, mutations: { retry: false } },
+ });
return render(
-
-
-
-
- ,
+
+
+
+
+
+
+ ,
);
};
@@ -100,18 +101,23 @@ vi.mock('react-router-dom', async () => {
};
});
-// Helper function to render with router
+// Helper function to render with router and QueryClient
const renderWithRouter = (
initialEntries: string[],